@@ -6,9 +6,9 @@
 */
 
 #include "kwalletmanagerwidget.h"
-#include "kwalletmanagerwidgetitem.h"
 #include "kwallet_interface.h"
 #include "kwalletmanager_debug.h"
+#include "kwalletmanagerwidgetitem.h"
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -17,8 +17,8 @@
 #include <QUrl>
 #include <QVBoxLayout>
 
-KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*flags*/):
-    KPageWidget(parent)
+KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*flags*/)
+    : KPageWidget(parent)
 {
     setFaceType(Auto);
     setAcceptDrops(true);
@@ -28,9 +28,8 @@ KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*fl
 
 KWalletManagerWidget::~KWalletManagerWidget() = default;
 
-void KWalletManagerWidget::onCurrentPageChanged(KPageWidgetItem */*current*/, KPageWidgetItem */*before*/)
+void KWalletManagerWidget::onCurrentPageChanged(KPageWidgetItem * /*current*/, KPageWidgetItem * /*before*/)
 {
-
 }
 
 void KWalletManagerWidget::updateWalletDisplay(const QString &selectWallet /* = QString() */)
@@ -83,7 +82,7 @@ bool KWalletManagerWidget::hasWallet(const QString &name) const
     return _walletPages.contains(name);
 }
 
-bool KWalletManagerWidget::openWalletFile(const QString &/*path*/)
+bool KWalletManagerWidget::openWalletFile(const QString & /*path*/)
 {
     Q_ASSERT(0);
     // TODO: implement this method: add a new tab with an editor centered on a file
@@ -120,78 +119,78 @@ void KWalletManagerWidget::dragEnterEvent(QDragEnterEvent *e)
     }
 }
 
-void KWalletManagerWidget::dragMoveEvent(QDragMoveEvent */*e*/)
+void KWalletManagerWidget::dragMoveEvent(QDragMoveEvent * /*e*/)
 {
     qCDebug(KWALLETMANAGER_LOG) << "KWalletManagerWidget::dragMoveEvent";
-//     KUrl dummy;
-//     QListWidgetItem *dummy2;
-//     if (shouldIgnoreDropEvent(e, &dummy, &dummy2)) {
-//         e->ignore();
-//     } else {
-//         e->accept();
-//     }
+    //     KUrl dummy;
+    //     QListWidgetItem *dummy2;
+    //     if (shouldIgnoreDropEvent(e, &dummy, &dummy2)) {
+    //         e->ignore();
+    //     } else {
+    //         e->accept();
+    //     }
 }
 
-void KWalletManagerWidget::dropEvent(QDropEvent */*e*/)
+void KWalletManagerWidget::dropEvent(QDropEvent * /*e*/)
 {
     qCDebug(KWALLETMANAGER_LOG) << "KWalletManagerWidget::dropEvent";
-//     KUrl u;
-//     QListWidgetItem *item;
-//     if (shouldIgnoreDropEvent(e, &u, &item)) {
-//         e->ignore();
-//         return;
-//     }
-//
-//     if (!item) {
-//         // Not dropped over an item thus it is a wallet
-//         const QString dest = KGlobal::dirs()->saveLocation("kwallet") + u.fileName();
-//         if (QFile::exists(dest)) {
-//             KMessageBox::error(viewport(), i18n("That wallet file already exists.  You cannot overwrite wallets."));
-//             e->ignore();
-//             return;
-//         }
-//
-//         // FIXME: verify that it is a real wallet file first
-//         KIO::NetAccess::file_copy(u, KUrl(dest));
-//         e->accept();
-//     } else {
-//         // Dropped over an item thus it is a folder
-//         KWalletItem *kwi = dynamic_cast<KWalletItem *>(item);
-//         Q_ASSERT(kwi);
-//         if (kwi) {
-//             kwi->processDropEvent(e);
-//         }
-//     }
+    //     KUrl u;
+    //     QListWidgetItem *item;
+    //     if (shouldIgnoreDropEvent(e, &u, &item)) {
+    //         e->ignore();
+    //         return;
+    //     }
+    //
+    //     if (!item) {
+    //         // Not dropped over an item thus it is a wallet
+    //         const QString dest = KGlobal::dirs()->saveLocation("kwallet") + u.fileName();
+    //         if (QFile::exists(dest)) {
+    //             KMessageBox::error(viewport(), i18n("That wallet file already exists.  You cannot overwrite wallets."));
+    //             e->ignore();
+    //             return;
+    //         }
+    //
+    //         // FIXME: verify that it is a real wallet file first
+    //         KIO::NetAccess::file_copy(u, KUrl(dest));
+    //         e->accept();
+    //     } else {
+    //         // Dropped over an item thus it is a folder
+    //         KWalletItem *kwi = dynamic_cast<KWalletItem *>(item);
+    //         Q_ASSERT(kwi);
+    //         if (kwi) {
+    //             kwi->processDropEvent(e);
+    //         }
+    //     }
 }
 
-bool KWalletManagerWidget::shouldIgnoreDropEvent(const QDropEvent */*e*/, QUrl */*u*/) const
+bool KWalletManagerWidget::shouldIgnoreDropEvent(const QDropEvent * /*e*/, QUrl * /*u*/) const
 {
     return false;
-//     if (e->source() == viewport()) {
-//         return true;
-//     }
-//
-//     if (!e->provides("application/x-kwallet-folder") &&
-//         !e->provides("application/x-kwallet-wallet") &&
-//         !e->provides("text/uri-list")) {
-//         return true;
-//     }
-//
-//     // Over wallets folders, over nothing wallets
-//     *item = itemAt(e->pos());
-//     const QByteArray edata = e->encodedData(item ? "application/x-kwallet-folder" : "application/x-kwallet-wallet");
-//     *u = decodeUrl(edata);
-//     if (*u == KUrl()) {
-//         *u = decodeUrl(e->encodedData("text/uri-list"));
-//     }
-//
-//     return *u == KUrl();
+    //     if (e->source() == viewport()) {
+    //         return true;
+    //     }
+    //
+    //     if (!e->provides("application/x-kwallet-folder") &&
+    //         !e->provides("application/x-kwallet-wallet") &&
+    //         !e->provides("text/uri-list")) {
+    //         return true;
+    //     }
+    //
+    //     // Over wallets folders, over nothing wallets
+    //     *item = itemAt(e->pos());
+    //     const QByteArray edata = e->encodedData(item ? "application/x-kwallet-folder" : "application/x-kwallet-wallet");
+    //     *u = decodeUrl(edata);
+    //     if (*u == KUrl()) {
+    //         *u = decodeUrl(e->encodedData("text/uri-list"));
+    //     }
+    //
+    //     return *u == KUrl();
 }
 
 bool KWalletManagerWidget::hasUnsavedChanges(const QString &name) const
 {
     if (name.isEmpty()) {
-        WalletPagesHash::const_iterator cp   = _walletPages.constBegin();
+        WalletPagesHash::const_iterator cp = _walletPages.constBegin();
         WalletPagesHash::const_iterator cend = _walletPages.constEnd();
         for (; cp != cend; ++cp) {
             if (cp.value()->hasUnsavedChanges()) {
@@ -202,13 +201,14 @@ bool KWalletManagerWidget::hasUnsavedChanges(const QString &name) const
     } else {
         WalletPagesHash::const_iterator it = _walletPages.find(name);
         if (it == _walletPages.constEnd()) {
-                return false;
+            return false;
         }
         return it.value()->hasUnsavedChanges();
     }
 }
 
-void KWalletManagerWidget::setErrorMessage(const QString &message) {
+void KWalletManagerWidget::setErrorMessage(const QString &message)
+{
     if (!_walletPages.isEmpty()) {
         return;
     }
@@ -219,10 +219,7 @@ void KWalletManagerWidget::setErrorMessage(const QString &message) {
         auto layout = new QVBoxLayout();
         placeholderWidget->setLayout(layout);
 
-        _errorLabel =
-            new QLabel(xi18nc("@info:status",
-                "An error occurred when connecting to the KWallet service:<nl/>%1",
-                message));
+        _errorLabel = new QLabel(xi18nc("@info:status", "An error occurred when connecting to the KWallet service:<nl/>%1", message));
         _errorLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
         layout->addWidget(_errorLabel);
 
